# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/crypto.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dapr/proto/runtime/v1/crypto.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a!dapr/proto/common/v1/common.proto\"\xb0\x01\n\x13SubtleGetKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x44\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x34.dapr.proto.runtime.v1.SubtleGetKeyRequest.KeyFormat\"\x1e\n\tKeyFormat\x12\x07\n\x03PEM\x10\x00\x12\x08\n\x04JSON\x10\x01\"C\n\x14SubtleGetKeyResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\"\xb6\x01\n\x14SubtleEncryptRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x06 \x01(\x0cR\x0e\x61ssociatedData\"8\n\x15SubtleEncryptResponse\x12\x12\n\nciphertext\x18\x01 \x01(\x0c\x12\x0b\n\x03tag\x18\x02 \x01(\x0c\"\xc4\x01\n\x14SubtleDecryptRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\x0b\n\x03tag\x18\x06 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x07 \x01(\x0cR\x0e\x61ssociatedData\"*\n\x15SubtleDecryptResponse\x12\x11\n\tplaintext\x18\x01 \x01(\x0c\"\xc8\x01\n\x14SubtleWrapKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12#\n\rplaintext_key\x18\x02 \x01(\x0cR\x0cplaintextKey\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x06 \x01(\x0cR\x0e\x61ssociatedData\"E\n\x15SubtleWrapKeyResponse\x12\x1f\n\x0bwrapped_key\x18\x01 \x01(\x0cR\nwrappedKey\x12\x0b\n\x03tag\x18\x02 \x01(\x0c\"\xd3\x01\n\x16SubtleUnwrapKeyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x1f\n\x0bwrapped_key\x18\x02 \x01(\x0cR\nwrappedKey\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\r\n\x05nonce\x18\x05 \x01(\x0c\x12\x0b\n\x03tag\x18\x06 \x01(\x0c\x12\'\n\x0f\x61ssociated_data\x18\x07 \x01(\x0cR\x0e\x61ssociatedData\">\n\x17SubtleUnwrapKeyResponse\x12#\n\rplaintext_key\x18\x01 \x01(\x0cR\x0cplaintextKey\"x\n\x11SubtleSignRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0e\n\x06\x64igest\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\"\'\n\x12SubtleSignResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\x8d\x01\n\x13SubtleVerifyRequest\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x0e\n\x06\x64igest\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\t\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12\x11\n\tsignature\x18\x05 \x01(\x0c\"%\n\x14SubtleVerifyResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x85\x01\n\x0e\x45ncryptRequest\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.dapr.proto.runtime.v1.EncryptRequestOptions\x12\x34\n\x07payload\x18\x02 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"\xfe\x01\n\x15\x45ncryptRequestOptions\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x19\n\x08key_name\x18\x02 \x01(\tR\x07keyName\x12\x1a\n\x12key_wrap_algorithm\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_encryption_cipher\x18\n \x01(\t\x12\x37\n\x18omit_decryption_key_name\x18\x0b \x01(\x08R\x15omitDecryptionKeyName\x12.\n\x13\x64\x65\x63ryption_key_name\x18\x0c \x01(\tR\x11\x64\x65\x63ryptionKeyName\"G\n\x0f\x45ncryptResponse\x12\x34\n\x07payload\x18\x01 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"\x85\x01\n\x0e\x44\x65\x63ryptRequest\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.dapr.proto.runtime.v1.DecryptRequestOptions\x12\x34\n\x07payload\x18\x02 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayload\"Y\n\x15\x44\x65\x63ryptRequestOptions\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12\x19\n\x08key_name\x18\x0c \x01(\tR\x07keyName\"G\n\x0f\x44\x65\x63ryptResponse\x12\x34\n\x07payload\x18\x01 \x01(\x0b\x32#.dapr.proto.common.v1.StreamPayloadBi\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_SUBTLEGETKEYREQUEST']._serialized_start=97
  _globals['_SUBTLEGETKEYREQUEST']._serialized_end=273
  _globals['_SUBTLEGETKEYREQUEST_KEYFORMAT']._serialized_start=243
  _globals['_SUBTLEGETKEYREQUEST_KEYFORMAT']._serialized_end=273
  _globals['_SUBTLEGETKEYRESPONSE']._serialized_start=275
  _globals['_SUBTLEGETKEYRESPONSE']._serialized_end=342
  _globals['_SUBTLEENCRYPTREQUEST']._serialized_start=345
  _globals['_SUBTLEENCRYPTREQUEST']._serialized_end=527
  _globals['_SUBTLEENCRYPTRESPONSE']._serialized_start=529
  _globals['_SUBTLEENCRYPTRESPONSE']._serialized_end=585
  _globals['_SUBTLEDECRYPTREQUEST']._serialized_start=588
  _globals['_SUBTLEDECRYPTREQUEST']._serialized_end=784
  _globals['_SUBTLEDECRYPTRESPONSE']._serialized_start=786
  _globals['_SUBTLEDECRYPTRESPONSE']._serialized_end=828
  _globals['_SUBTLEWRAPKEYREQUEST']._serialized_start=831
  _globals['_SUBTLEWRAPKEYREQUEST']._serialized_end=1031
  _globals['_SUBTLEWRAPKEYRESPONSE']._serialized_start=1033
  _globals['_SUBTLEWRAPKEYRESPONSE']._serialized_end=1102
  _globals['_SUBTLEUNWRAPKEYREQUEST']._serialized_start=1105
  _globals['_SUBTLEUNWRAPKEYREQUEST']._serialized_end=1316
  _globals['_SUBTLEUNWRAPKEYRESPONSE']._serialized_start=1318
  _globals['_SUBTLEUNWRAPKEYRESPONSE']._serialized_end=1380
  _globals['_SUBTLESIGNREQUEST']._serialized_start=1382
  _globals['_SUBTLESIGNREQUEST']._serialized_end=1502
  _globals['_SUBTLESIGNRESPONSE']._serialized_start=1504
  _globals['_SUBTLESIGNRESPONSE']._serialized_end=1543
  _globals['_SUBTLEVERIFYREQUEST']._serialized_start=1546
  _globals['_SUBTLEVERIFYREQUEST']._serialized_end=1687
  _globals['_SUBTLEVERIFYRESPONSE']._serialized_start=1689
  _globals['_SUBTLEVERIFYRESPONSE']._serialized_end=1726
  _globals['_ENCRYPTREQUEST']._serialized_start=1729
  _globals['_ENCRYPTREQUEST']._serialized_end=1862
  _globals['_ENCRYPTREQUESTOPTIONS']._serialized_start=1865
  _globals['_ENCRYPTREQUESTOPTIONS']._serialized_end=2119
  _globals['_ENCRYPTRESPONSE']._serialized_start=2121
  _globals['_ENCRYPTRESPONSE']._serialized_end=2192
  _globals['_DECRYPTREQUEST']._serialized_start=2195
  _globals['_DECRYPTREQUEST']._serialized_end=2328
  _globals['_DECRYPTREQUESTOPTIONS']._serialized_start=2330
  _globals['_DECRYPTREQUESTOPTIONS']._serialized_end=2419
  _globals['_DECRYPTRESPONSE']._serialized_start=2421
  _globals['_DECRYPTRESPONSE']._serialized_end=2492
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/configuration.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/configuration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)dapr/proto/runtime/v1/configuration.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a!dapr/proto/common/v1/common.proto\"\xbc\x01\n\x17GetConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12N\n\x08metadata\x18\x03 \x03(\x0b\x32<.dapr.proto.runtime.v1.GetConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x18GetConfigurationResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"\xc8\x01\n\x1dSubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12T\n\x08metadata\x18\x03 \x03(\x0b\x32\x42.dapr.proto.runtime.v1.SubscribeConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x1fUnsubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xd4\x01\n\x1eSubscribeConfigurationResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.dapr.proto.runtime.v1.SubscribeConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"?\n UnsubscribeConfigurationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tBi\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.configuration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._loaded_options = None
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._loaded_options = None
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=104
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=292
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_start=245
  _globals['_GETCONFIGURATIONREQUEST_METADATAENTRY']._serialized_end=292
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_start=295
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_end=483
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_start=398
  _globals['_GETCONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_end=483
  _globals['_SUBSCRIBECONFIGURATIONREQUEST']._serialized_start=486
  _globals['_SUBSCRIBECONFIGURATIONREQUEST']._serialized_end=686
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_start=245
  _globals['_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY']._serialized_end=292
  _globals['_UNSUBSCRIBECONFIGURATIONREQUEST']._serialized_start=688
  _globals['_UNSUBSCRIBECONFIGURATIONREQUEST']._serialized_end=753
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE']._serialized_start=756
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE']._serialized_end=968
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_start=398
  _globals['_SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY']._serialized_end=483
  _globals['_UNSUBSCRIBECONFIGURATIONRESPONSE']._serialized_start=970
  _globals['_UNSUBSCRIBECONFIGURATIONRESPONSE']._serialized_end=1033
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dapr/proto/runtime/v1/state.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a!dapr/proto/common/v1/common.proto\"\xf5\x01\n\x0fGetStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\x0b\x63onsistency\x18\x03 \x01(\x0e\x32\x33.dapr.proto.common.v1.StateOptions.StateConsistency\x12\x46\n\x08metadata\x18\x04 \x03(\x0b\x32\x34.dapr.proto.runtime.v1.GetStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x13GetBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0bparallelism\x18\x03 \x01(\x05\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x14GetBulkStateResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32$.dapr.proto.runtime.v1.BulkStateItem\"\xbe\x01\n\rBulkStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x44\n\x08metadata\x18\x05 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.BulkStateItem.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x10GetStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x02\n\x12\x44\x65leteStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12(\n\x04\x65tag\x18\x03 \x01(\x0b\x32\x1a.dapr.proto.common.v1.Etag\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".dapr.proto.common.v1.StateOptions\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x16\x44\x65leteBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"W\n\x10SaveStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\xbc\x01\n\x11QueryStateRequest\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\r\n\x05query\x18\x02 \x01(\t\x12H\n\x08metadata\x18\x03 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eQueryStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xd7\x01\n\x12QueryStateResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.dapr.proto.runtime.v1.QueryStateItem\x12\r\n\x05token\x18\x02 \x01(\t\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x1bTransactionalStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x30\n\x07request\x18\x02 \x01(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\x83\x02\n\x1e\x45xecuteStateTransactionRequest\x12\x11\n\tstoreName\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.TransactionalStateOperation\x12U\n\x08metadata\x18\x03 \x03(\x0b\x32\x43.dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_GETSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BULKSTATEITEM_METADATAENTRY']._loaded_options = None
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATEREQUEST']._serialized_start=96
  _globals['_GETSTATEREQUEST']._serialized_end=341
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_GETSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_GETBULKSTATEREQUEST']._serialized_start=344
  _globals['_GETBULKSTATEREQUEST']._serialized_end=545
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_GETBULKSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_GETBULKSTATERESPONSE']._serialized_start=547
  _globals['_GETBULKSTATERESPONSE']._serialized_end=622
  _globals['_BULKSTATEITEM']._serialized_start=625
  _globals['_BULKSTATEITEM']._serialized_end=815
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_start=294
  _globals['_BULKSTATEITEM_METADATAENTRY']._serialized_end=341
  _globals['_GETSTATERESPONSE']._serialized_start=818
  _globals['_GETSTATERESPONSE']._serialized_end=986
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_start=294
  _globals['_GETSTATERESPONSE_METADATAENTRY']._serialized_end=341
  _globals['_DELETESTATEREQUEST']._serialized_start=989
  _globals['_DELETESTATEREQUEST']._serialized_end=1261
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_DELETESTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_DELETEBULKSTATEREQUEST']._serialized_start=1263
  _globals['_DELETEBULKSTATEREQUEST']._serialized_end=1356
  _globals['_SAVESTATEREQUEST']._serialized_start=1358
  _globals['_SAVESTATEREQUEST']._serialized_end=1445
  _globals['_QUERYSTATEREQUEST']._serialized_start=1448
  _globals['_QUERYSTATEREQUEST']._serialized_end=1636
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_QUERYSTATEREQUEST_METADATAENTRY']._serialized_end=341
  _globals['_QUERYSTATEITEM']._serialized_start=1638
  _globals['_QUERYSTATEITEM']._serialized_end=1710
  _globals['_QUERYSTATERESPONSE']._serialized_start=1713
  _globals['_QUERYSTATERESPONSE']._serialized_end=1928
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_start=294
  _globals['_QUERYSTATERESPONSE_METADATAENTRY']._serialized_end=341
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_start=1930
  _globals['_TRANSACTIONALSTATEOPERATION']._serialized_end=2032
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_start=2035
  _globals['_EXECUTESTATETRANSACTIONREQUEST']._serialized_end=2294
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_start=294
  _globals['_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY']._serialized_end=341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/ai.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/ai.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64\x61pr/proto/runtime/v1/ai.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xeb\x03\n\x13\x43onversationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\tcontextID\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x06inputs\x18\x03 \x03(\x0b\x32(.dapr.proto.runtime.v1.ConversationInput\x12N\n\nparameters\x18\x04 \x03(\x0b\x32:.dapr.proto.runtime.v1.ConversationRequest.ParametersEntry\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.ConversationRequest.MetadataEntry\x12\x15\n\x08scrubPII\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0btemperature\x18\x07 \x01(\x01H\x02\x88\x01\x01\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x02\x18\x01\x42\x0c\n\n_contextIDB\x0b\n\t_scrubPIIB\x0e\n\x0c_temperature\"\xe6\x04\n\x19\x43onversationRequestAlpha2\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\ncontext_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12>\n\x06inputs\x18\x03 \x03(\x0b\x32..dapr.proto.runtime.v1.ConversationInputAlpha2\x12T\n\nparameters\x18\x04 \x03(\x0b\x32@.dapr.proto.runtime.v1.ConversationRequestAlpha2.ParametersEntry\x12P\n\x08metadata\x18\x05 \x03(\x0b\x32>.dapr.proto.runtime.v1.ConversationRequestAlpha2.MetadataEntry\x12\x16\n\tscrub_pii\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0btemperature\x18\x07 \x01(\x01H\x02\x88\x01\x01\x12\x37\n\x05tools\x18\x08 \x03(\x0b\x32(.dapr.proto.runtime.v1.ConversationTools\x12\x18\n\x0btool_choice\x18\t \x01(\tH\x03\x88\x01\x01\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_context_idB\x0c\n\n_scrub_piiB\x0e\n\x0c_temperatureB\x0e\n\x0c_tool_choice\"h\n\x11\x43onversationInput\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\x04role\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08scrubPII\x18\x03 \x01(\x08H\x01\x88\x01\x01:\x02\x18\x01\x42\x07\n\x05_roleB\x0b\n\t_scrubPII\"}\n\x17\x43onversationInputAlpha2\x12<\n\x08messages\x18\x01 \x03(\x0b\x32*.dapr.proto.runtime.v1.ConversationMessage\x12\x16\n\tscrub_pii\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_scrub_pii\"\x97\x03\n\x13\x43onversationMessage\x12M\n\x0cof_developer\x18\x01 \x01(\x0b\x32\x35.dapr.proto.runtime.v1.ConversationMessageOfDeveloperH\x00\x12G\n\tof_system\x18\x02 \x01(\x0b\x32\x32.dapr.proto.runtime.v1.ConversationMessageOfSystemH\x00\x12\x43\n\x07of_user\x18\x03 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationMessageOfUserH\x00\x12M\n\x0cof_assistant\x18\x04 \x01(\x0b\x32\x35.dapr.proto.runtime.v1.ConversationMessageOfAssistantH\x00\x12\x43\n\x07of_tool\x18\x05 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationMessageOfToolH\x00\x42\x0f\n\rmessage_types\"\x80\x01\n\x1e\x43onversationMessageOfDeveloper\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"}\n\x1b\x43onversationMessageOfSystem\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"{\n\x19\x43onversationMessageOfUser\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\x07\n\x05_name\"\xc2\x01\n\x1e\x43onversationMessageOfAssistant\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContent\x12@\n\ntool_calls\x18\x03 \x03(\x0b\x32,.dapr.proto.runtime.v1.ConversationToolCallsB\x07\n\x05_name\"\x8f\x01\n\x19\x43onversationMessageOfTool\x12\x14\n\x07tool_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x07\x63ontent\x18\x03 \x03(\x0b\x32\x31.dapr.proto.runtime.v1.ConversationMessageContentB\n\n\x08_tool_id\"\x89\x01\n\x15\x43onversationToolCalls\x12\x0f\n\x02id\x18\x01 \x01(\tH\x01\x88\x01\x01\x12J\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x36.dapr.proto.runtime.v1.ConversationToolCallsOfFunctionH\x00\x42\x0c\n\ntool_typesB\x05\n\x03_id\"B\n\x1f\x43onversationToolCallsOfFunction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x01(\t\"*\n\x1a\x43onversationMessageContent\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xc0\x01\n\x12\x43onversationResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.ConversationResult.ParametersEntry\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01:\x02\x18\x01\"]\n\x18\x43onversationResultAlpha2\x12\x41\n\x07\x63hoices\x18\x01 \x03(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationResultChoices\"\x84\x01\n\x19\x43onversationResultChoices\x12\x15\n\rfinish_reason\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x41\n\x07message\x18\x03 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationResultMessage\"n\n\x19\x43onversationResultMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12@\n\ntool_calls\x18\x02 \x03(\x0b\x32,.dapr.proto.runtime.v1.ConversationToolCalls\"|\n\x14\x43onversationResponse\x12\x16\n\tcontextID\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\x07outputs\x18\x02 \x03(\x0b\x32).dapr.proto.runtime.v1.ConversationResult:\x02\x18\x01\x42\x0c\n\n_contextID\"\x86\x01\n\x1a\x43onversationResponseAlpha2\x12\x17\n\ncontext_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x07outputs\x18\x02 \x03(\x0b\x32/.dapr.proto.runtime.v1.ConversationResultAlpha2B\r\n\x0b_context_id\"g\n\x11\x43onversationTools\x12\x44\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x30.dapr.proto.runtime.v1.ConversationToolsFunctionH\x00\x42\x0c\n\ntool_types\"\x80\x01\n\x19\x43onversationToolsFunction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0e\n\x0c_descriptionBi\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.ai_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUEST']._loaded_options = None
  _globals['_CONVERSATIONREQUEST']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._loaded_options = None
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONINPUT']._loaded_options = None
  _globals['_CONVERSATIONINPUT']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CONVERSATIONRESULT']._loaded_options = None
  _globals['_CONVERSATIONRESULT']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONRESPONSE']._loaded_options = None
  _globals['_CONVERSATIONRESPONSE']._serialized_options = b'\030\001'
  _globals['_CONVERSATIONREQUEST']._serialized_start=115
  _globals['_CONVERSATIONREQUEST']._serialized_end=606
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONREQUEST_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_start=512
  _globals['_CONVERSATIONREQUEST_METADATAENTRY']._serialized_end=559
  _globals['_CONVERSATIONREQUESTALPHA2']._serialized_start=609
  _globals['_CONVERSATIONREQUESTALPHA2']._serialized_end=1223
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONREQUESTALPHA2_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_start=512
  _globals['_CONVERSATIONREQUESTALPHA2_METADATAENTRY']._serialized_end=559
  _globals['_CONVERSATIONINPUT']._serialized_start=1225
  _globals['_CONVERSATIONINPUT']._serialized_end=1329
  _globals['_CONVERSATIONINPUTALPHA2']._serialized_start=1331
  _globals['_CONVERSATIONINPUTALPHA2']._serialized_end=1456
  _globals['_CONVERSATIONMESSAGE']._serialized_start=1459
  _globals['_CONVERSATIONMESSAGE']._serialized_end=1866
  _globals['_CONVERSATIONMESSAGEOFDEVELOPER']._serialized_start=1869
  _globals['_CONVERSATIONMESSAGEOFDEVELOPER']._serialized_end=1997
  _globals['_CONVERSATIONMESSAGEOFSYSTEM']._serialized_start=1999
  _globals['_CONVERSATIONMESSAGEOFSYSTEM']._serialized_end=2124
  _globals['_CONVERSATIONMESSAGEOFUSER']._serialized_start=2126
  _globals['_CONVERSATIONMESSAGEOFUSER']._serialized_end=2249
  _globals['_CONVERSATIONMESSAGEOFASSISTANT']._serialized_start=2252
  _globals['_CONVERSATIONMESSAGEOFASSISTANT']._serialized_end=2446
  _globals['_CONVERSATIONMESSAGEOFTOOL']._serialized_start=2449
  _globals['_CONVERSATIONMESSAGEOFTOOL']._serialized_end=2592
  _globals['_CONVERSATIONTOOLCALLS']._serialized_start=2595
  _globals['_CONVERSATIONTOOLCALLS']._serialized_end=2732
  _globals['_CONVERSATIONTOOLCALLSOFFUNCTION']._serialized_start=2734
  _globals['_CONVERSATIONTOOLCALLSOFFUNCTION']._serialized_end=2800
  _globals['_CONVERSATIONMESSAGECONTENT']._serialized_start=2802
  _globals['_CONVERSATIONMESSAGECONTENT']._serialized_end=2844
  _globals['_CONVERSATIONRESULT']._serialized_start=2847
  _globals['_CONVERSATIONRESULT']._serialized_end=3039
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_start=439
  _globals['_CONVERSATIONRESULT_PARAMETERSENTRY']._serialized_end=510
  _globals['_CONVERSATIONRESULTALPHA2']._serialized_start=3041
  _globals['_CONVERSATIONRESULTALPHA2']._serialized_end=3134
  _globals['_CONVERSATIONRESULTCHOICES']._serialized_start=3137
  _globals['_CONVERSATIONRESULTCHOICES']._serialized_end=3269
  _globals['_CONVERSATIONRESULTMESSAGE']._serialized_start=3271
  _globals['_CONVERSATIONRESULTMESSAGE']._serialized_end=3381
  _globals['_CONVERSATIONRESPONSE']._serialized_start=3383
  _globals['_CONVERSATIONRESPONSE']._serialized_end=3507
  _globals['_CONVERSATIONRESPONSEALPHA2']._serialized_start=3510
  _globals['_CONVERSATIONRESPONSEALPHA2']._serialized_end=3644
  _globals['_CONVERSATIONTOOLS']._serialized_start=3646
  _globals['_CONVERSATIONTOOLS']._serialized_end=3749
  _globals['_CONVERSATIONTOOLSFUNCTION']._serialized_start=3752
  _globals['_CONVERSATIONTOOLSFUNCTION']._serialized_end=3880
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

Copyright 2025 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import dapr.proto.common.v1.common_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SubtleGetKeyRequest(google.protobuf.message.Message):
    """SubtleGetKeyRequest is the request object for SubtleGetKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _KeyFormat:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _KeyFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SubtleGetKeyRequest._KeyFormat.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PEM: SubtleGetKeyRequest._KeyFormat.ValueType  # 0
        """PEM (PKIX) (default)"""
        JSON: SubtleGetKeyRequest._KeyFormat.ValueType  # 1
        """JSON (JSON Web Key) as string"""

    class KeyFormat(_KeyFormat, metaclass=_KeyFormatEnumTypeWrapper): ...
    PEM: SubtleGetKeyRequest.KeyFormat.ValueType  # 0
    """PEM (PKIX) (default)"""
    JSON: SubtleGetKeyRequest.KeyFormat.ValueType  # 1
    """JSON (JSON Web Key) as string"""

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    name: builtins.str
    """Name (or name/version) of the key to use in the key vault"""
    format: Global___SubtleGetKeyRequest.KeyFormat.ValueType
    """Response format"""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        name: builtins.str = ...,
        format: Global___SubtleGetKeyRequest.KeyFormat.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["component_name", b"component_name", "format", b"format", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleGetKeyRequest: typing_extensions.TypeAlias = SubtleGetKeyRequest

@typing.final
class SubtleGetKeyResponse(google.protobuf.message.Message):
    """SubtleGetKeyResponse is the response for SubtleGetKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name (or name/version) of the key.
    This is returned as response too in case there is a version.
    """
    public_key: builtins.str
    """Public key, encoded in the requested format"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        public_key: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["name", b"name", "public_key", b"public_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleGetKeyResponse: typing_extensions.TypeAlias = SubtleGetKeyResponse

@typing.final
class SubtleEncryptRequest(google.protobuf.message.Message):
    """SubtleEncryptRequest is the request for SubtleEncryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    ASSOCIATED_DATA_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    plaintext: builtins.bytes
    """Message to encrypt."""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    nonce: builtins.bytes
    """Nonce / initialization vector.
    Ignored with asymmetric ciphers.
    """
    associated_data: builtins.bytes
    """Associated Data when using AEAD ciphers (optional)."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        plaintext: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
        nonce: builtins.bytes = ...,
        associated_data: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "associated_data", b"associated_data", "component_name", b"component_name", "key_name", b"key_name", "nonce", b"nonce", "plaintext", b"plaintext"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleEncryptRequest: typing_extensions.TypeAlias = SubtleEncryptRequest

@typing.final
class SubtleEncryptResponse(google.protobuf.message.Message):
    """SubtleEncryptResponse is the response for SubtleEncryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIPHERTEXT_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    ciphertext: builtins.bytes
    """Encrypted ciphertext."""
    tag: builtins.bytes
    """Authentication tag.
    This is nil when not using an authenticated cipher.
    """
    def __init__(
        self,
        *,
        ciphertext: builtins.bytes = ...,
        tag: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["ciphertext", b"ciphertext", "tag", b"tag"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleEncryptResponse: typing_extensions.TypeAlias = SubtleEncryptResponse

@typing.final
class SubtleDecryptRequest(google.protobuf.message.Message):
    """SubtleDecryptRequest is the request for SubtleDecryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    ASSOCIATED_DATA_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    ciphertext: builtins.bytes
    """Message to decrypt."""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    nonce: builtins.bytes
    """Nonce / initialization vector.
    Ignored with asymmetric ciphers.
    """
    tag: builtins.bytes
    """Authentication tag.
    This is nil when not using an authenticated cipher.
    """
    associated_data: builtins.bytes
    """Associated Data when using AEAD ciphers (optional)."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        ciphertext: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
        nonce: builtins.bytes = ...,
        tag: builtins.bytes = ...,
        associated_data: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "associated_data", b"associated_data", "ciphertext", b"ciphertext", "component_name", b"component_name", "key_name", b"key_name", "nonce", b"nonce", "tag", b"tag"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleDecryptRequest: typing_extensions.TypeAlias = SubtleDecryptRequest

@typing.final
class SubtleDecryptResponse(google.protobuf.message.Message):
    """SubtleDecryptResponse is the response for SubtleDecryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAINTEXT_FIELD_NUMBER: builtins.int
    plaintext: builtins.bytes
    """Decrypted plaintext."""
    def __init__(
        self,
        *,
        plaintext: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["plaintext", b"plaintext"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleDecryptResponse: typing_extensions.TypeAlias = SubtleDecryptResponse

@typing.final
class SubtleWrapKeyRequest(google.protobuf.message.Message):
    """SubtleWrapKeyRequest is the request for SubtleWrapKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    PLAINTEXT_KEY_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    ASSOCIATED_DATA_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    plaintext_key: builtins.bytes
    """Key to wrap"""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    nonce: builtins.bytes
    """Nonce / initialization vector.
    Ignored with asymmetric ciphers.
    """
    associated_data: builtins.bytes
    """Associated Data when using AEAD ciphers (optional)."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        plaintext_key: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
        nonce: builtins.bytes = ...,
        associated_data: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "associated_data", b"associated_data", "component_name", b"component_name", "key_name", b"key_name", "nonce", b"nonce", "plaintext_key", b"plaintext_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleWrapKeyRequest: typing_extensions.TypeAlias = SubtleWrapKeyRequest

@typing.final
class SubtleWrapKeyResponse(google.protobuf.message.Message):
    """SubtleWrapKeyResponse is the response for SubtleWrapKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WRAPPED_KEY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    wrapped_key: builtins.bytes
    """Wrapped key."""
    tag: builtins.bytes
    """Authentication tag.
    This is nil when not using an authenticated cipher.
    """
    def __init__(
        self,
        *,
        wrapped_key: builtins.bytes = ...,
        tag: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["tag", b"tag", "wrapped_key", b"wrapped_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleWrapKeyResponse: typing_extensions.TypeAlias = SubtleWrapKeyResponse

@typing.final
class SubtleUnwrapKeyRequest(google.protobuf.message.Message):
    """SubtleUnwrapKeyRequest is the request for SubtleUnwrapKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    WRAPPED_KEY_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    ASSOCIATED_DATA_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    wrapped_key: builtins.bytes
    """Wrapped key."""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    nonce: builtins.bytes
    """Nonce / initialization vector.
    Ignored with asymmetric ciphers.
    """
    tag: builtins.bytes
    """Authentication tag.
    This is nil when not using an authenticated cipher.
    """
    associated_data: builtins.bytes
    """Associated Data when using AEAD ciphers (optional)."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        wrapped_key: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
        nonce: builtins.bytes = ...,
        tag: builtins.bytes = ...,
        associated_data: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "associated_data", b"associated_data", "component_name", b"component_name", "key_name", b"key_name", "nonce", b"nonce", "tag", b"tag", "wrapped_key", b"wrapped_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleUnwrapKeyRequest: typing_extensions.TypeAlias = SubtleUnwrapKeyRequest

@typing.final
class SubtleUnwrapKeyResponse(google.protobuf.message.Message):
    """SubtleUnwrapKeyResponse is the response for SubtleUnwrapKeyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAINTEXT_KEY_FIELD_NUMBER: builtins.int
    plaintext_key: builtins.bytes
    """Key in plaintext"""
    def __init__(
        self,
        *,
        plaintext_key: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["plaintext_key", b"plaintext_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleUnwrapKeyResponse: typing_extensions.TypeAlias = SubtleUnwrapKeyResponse

@typing.final
class SubtleSignRequest(google.protobuf.message.Message):
    """SubtleSignRequest is the request for SubtleSignAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    digest: builtins.bytes
    """Digest to sign."""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        digest: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "component_name", b"component_name", "digest", b"digest", "key_name", b"key_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleSignRequest: typing_extensions.TypeAlias = SubtleSignRequest

@typing.final
class SubtleSignResponse(google.protobuf.message.Message):
    """SubtleSignResponse is the response for SubtleSignAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_FIELD_NUMBER: builtins.int
    signature: builtins.bytes
    """The signature that was computed"""
    def __init__(
        self,
        *,
        signature: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["signature", b"signature"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleSignResponse: typing_extensions.TypeAlias = SubtleSignResponse

@typing.final
class SubtleVerifyRequest(google.protobuf.message.Message):
    """SubtleVerifyRequest is the request for SubtleVerifyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    digest: builtins.bytes
    """Digest of the message."""
    algorithm: builtins.str
    """Algorithm to use, as in the JWA standard."""
    key_name: builtins.str
    """Name (or name/version) of the key."""
    signature: builtins.bytes
    """Signature to verify."""
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        digest: builtins.bytes = ...,
        algorithm: builtins.str = ...,
        key_name: builtins.str = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["algorithm", b"algorithm", "component_name", b"component_name", "digest", b"digest", "key_name", b"key_name", "signature", b"signature"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleVerifyRequest: typing_extensions.TypeAlias = SubtleVerifyRequest

@typing.final
class SubtleVerifyResponse(google.protobuf.message.Message):
    """SubtleVerifyResponse is the response for SubtleVerifyAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_FIELD_NUMBER: builtins.int
    valid: builtins.bool
    """True if the signature is valid."""
    def __init__(
        self,
        *,
        valid: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["valid", b"valid"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtleVerifyResponse: typing_extensions.TypeAlias = SubtleVerifyResponse

@typing.final
class EncryptRequest(google.protobuf.message.Message):
    """EncryptRequest is the request for EncryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> Global___EncryptRequestOptions:
        """Request details. Must be present in the first message only."""

    @property
    def payload(self) -> dapr.proto.common.v1.common_pb2.StreamPayload:
        """Chunk of data of arbitrary size."""

    def __init__(
        self,
        *,
        options: Global___EncryptRequestOptions | None = ...,
        payload: dapr.proto.common.v1.common_pb2.StreamPayload | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["options", b"options", "payload", b"payload"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["options", b"options", "payload", b"payload"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EncryptRequest: typing_extensions.TypeAlias = EncryptRequest

@typing.final
class EncryptRequestOptions(google.protobuf.message.Message):
    """EncryptRequestOptions contains options for the first message in the EncryptAlpha1 request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    KEY_WRAP_ALGORITHM_FIELD_NUMBER: builtins.int
    DATA_ENCRYPTION_CIPHER_FIELD_NUMBER: builtins.int
    OMIT_DECRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    DECRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component. Required."""
    key_name: builtins.str
    """Name (or name/version) of the key. Required."""
    key_wrap_algorithm: builtins.str
    """Key wrapping algorithm to use. Required.
    Supported options include: A256KW (alias: AES), A128CBC, A192CBC, A256CBC, RSA-OAEP-256 (alias: RSA).
    """
    data_encryption_cipher: builtins.str
    """Cipher used to encrypt data (optional): "aes-gcm" (default) or "chacha20-poly1305" """
    omit_decryption_key_name: builtins.bool
    """If true, the encrypted document does not contain a key reference.
    In that case, calls to the Decrypt method must provide a key reference (name or name/version).
    Defaults to false.
    """
    decryption_key_name: builtins.str
    """Key reference to embed in the encrypted document (name or name/version).
    This is helpful if the reference of the key used to decrypt the document is different from the one used to encrypt it.
    If unset, uses the reference of the key used to encrypt the document (this is the default behavior).
    This option is ignored if omit_decryption_key_name is true.
    """
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        key_name: builtins.str = ...,
        key_wrap_algorithm: builtins.str = ...,
        data_encryption_cipher: builtins.str = ...,
        omit_decryption_key_name: builtins.bool = ...,
        decryption_key_name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["component_name", b"component_name", "data_encryption_cipher", b"data_encryption_cipher", "decryption_key_name", b"decryption_key_name", "key_name", b"key_name", "key_wrap_algorithm", b"key_wrap_algorithm", "omit_decryption_key_name", b"omit_decryption_key_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EncryptRequestOptions: typing_extensions.TypeAlias = EncryptRequestOptions

@typing.final
class EncryptResponse(google.protobuf.message.Message):
    """EncryptResponse is the response for EncryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> dapr.proto.common.v1.common_pb2.StreamPayload:
        """Chunk of data."""

    def __init__(
        self,
        *,
        payload: dapr.proto.common.v1.common_pb2.StreamPayload | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["payload", b"payload"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["payload", b"payload"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EncryptResponse: typing_extensions.TypeAlias = EncryptResponse

@typing.final
class DecryptRequest(google.protobuf.message.Message):
    """DecryptRequest is the request for DecryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> Global___DecryptRequestOptions:
        """Request details. Must be present in the first message only."""

    @property
    def payload(self) -> dapr.proto.common.v1.common_pb2.StreamPayload:
        """Chunk of data of arbitrary size."""

    def __init__(
        self,
        *,
        options: Global___DecryptRequestOptions | None = ...,
        payload: dapr.proto.common.v1.common_pb2.StreamPayload | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["options", b"options", "payload", b"payload"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["options", b"options", "payload", b"payload"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DecryptRequest: typing_extensions.TypeAlias = DecryptRequest

@typing.final
class DecryptRequestOptions(google.protobuf.message.Message):
    """DecryptRequestOptions contains options for the first message in the DecryptAlpha1 request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    """Name of the component"""
    key_name: builtins.str
    """Name (or name/version) of the key to decrypt the message.
    Overrides any key reference included in the message if present.
    This is required if the message doesn't include a key reference (i.e. was created with omit_decryption_key_name set to true).
    """
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        key_name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["component_name", b"component_name", "key_name", b"key_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DecryptRequestOptions: typing_extensions.TypeAlias = DecryptRequestOptions

@typing.final
class DecryptResponse(google.protobuf.message.Message):
    """DecryptResponse is the response for DecryptAlpha1."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> dapr.proto.common.v1.common_pb2.StreamPayload:
        """Chunk of data."""

    def __init__(
        self,
        *,
        payload: dapr.proto.common.v1.common_pb2.StreamPayload | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["payload", b"payload"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["payload", b"payload"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DecryptResponse: typing_extensions.TypeAlias = DecryptResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

Copyright 2025 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import collections.abc
import dapr.proto.common.v1.common_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Job(google.protobuf.message.Message):
    """Job is the definition of a job. At least one of schedule or due_time must be
    provided but can also be provided together.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    REPEATS_FIELD_NUMBER: builtins.int
    DUE_TIME_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The unique name for the job."""
    schedule: builtins.str
    """schedule is an optional schedule at which the job is to be run.
    Accepts both systemd timer style cron expressions, as well as human
    readable '@' prefixed period strings as defined below.

    Systemd timer style cron accepts 6 fields:
    seconds | minutes | hours | day of month | month        | day of week
    0-59    | 0-59    | 0-23  | 1-31         | 1-12/jan-dec | 0-6/sun-sat

    "0 30 * * * *" - every hour on the half hour
    "0 15 3 * * *" - every day at 03:15

    Period string expressions:
    Entry                  | Description                                  | Equivalent To
    -----                  | -----------                                  | -------------
    @every `<duration>`    | Run every `<duration>` (e.g. '@every 1h30m') | N/A
    @yearly (or @annually) | Run once a year, midnight, Jan. 1st          | 0 0 0 1 1 *
    @monthly               | Run once a month, midnight, first of month   | 0 0 0 1 * *
    @weekly                | Run once a week, midnight on Sunday          | 0 0 0 * * 0
    @daily (or @midnight)  | Run once a day, midnight                     | 0 0 0 * * *
    @hourly                | Run once an hour, beginning of hour          | 0 0 * * * *
    """
    repeats: builtins.int
    """repeats is the optional number of times in which the job should be
    triggered. If not set, the job will run indefinitely or until expiration.
    """
    due_time: builtins.str
    """due_time is the optional time at which the job should be active, or the
    "one shot" time if other scheduling type fields are not provided. Accepts
    a "point in time" string in the format of RFC3339, Go duration string
    (calculated from job creation time), or non-repeating ISO8601.
    """
    ttl: builtins.str
    """ttl is the optional time to live or expiration of the job. Accepts a
    "point in time" string in the format of RFC3339, Go duration string
    (calculated from job creation time), or non-repeating ISO8601.
    """
    @property
    def data(self) -> google.protobuf.any_pb2.Any:
        """payload is the serialized job payload that will be sent to the recipient
        when the job is triggered.
        """

    @property
    def failure_policy(self) -> dapr.proto.common.v1.common_pb2.JobFailurePolicy:
        """failure_policy is the optional policy for handling job failures."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        schedule: builtins.str | None = ...,
        repeats: builtins.int | None = ...,
        due_time: builtins.str | None = ...,
        ttl: builtins.str | None = ...,
        data: google.protobuf.any_pb2.Any | None = ...,
        failure_policy: dapr.proto.common.v1.common_pb2.JobFailurePolicy | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_due_time", b"_due_time", "_failure_policy", b"_failure_policy", "_repeats", b"_repeats", "_schedule", b"_schedule", "_ttl", b"_ttl", "data", b"data", "due_time", b"due_time", "failure_policy", b"failure_policy", "repeats", b"repeats", "schedule", b"schedule", "ttl", b"ttl"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_due_time", b"_due_time", "_failure_policy", b"_failure_policy", "_repeats", b"_repeats", "_schedule", b"_schedule", "_ttl", b"_ttl", "data", b"data", "due_time", b"due_time", "failure_policy", b"failure_policy", "name", b"name", "repeats", b"repeats", "schedule", b"schedule", "ttl", b"ttl"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__due_time: typing_extensions.TypeAlias = typing.Literal["due_time"]
    _WhichOneofArgType__due_time: typing_extensions.TypeAlias = typing.Literal["_due_time", b"_due_time"]
    _WhichOneofReturnType__failure_policy: typing_extensions.TypeAlias = typing.Literal["failure_policy"]
    _WhichOneofArgType__failure_policy: typing_extensions.TypeAlias = typing.Literal["_failure_policy", b"_failure_policy"]
    _WhichOneofReturnType__repeats: typing_extensions.TypeAlias = typing.Literal["repeats"]
    _WhichOneofArgType__repeats: typing_extensions.TypeAlias = typing.Literal["_repeats", b"_repeats"]
    _WhichOneofReturnType__schedule: typing_extensions.TypeAlias = typing.Literal["schedule"]
    _WhichOneofArgType__schedule: typing_extensions.TypeAlias = typing.Literal["_schedule", b"_schedule"]
    _WhichOneofReturnType__ttl: typing_extensions.TypeAlias = typing.Literal["ttl"]
    _WhichOneofArgType__ttl: typing_extensions.TypeAlias = typing.Literal["_ttl", b"_ttl"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__due_time) -> _WhichOneofReturnType__due_time | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__failure_policy) -> _WhichOneofReturnType__failure_policy | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__repeats) -> _WhichOneofReturnType__repeats | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__schedule) -> _WhichOneofReturnType__schedule | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__ttl) -> _WhichOneofReturnType__ttl | None: ...

Global___Job: typing_extensions.TypeAlias = Job

@typing.final
class ScheduleJobRequest(google.protobuf.message.Message):
    """ScheduleJobRequest is the message to create/schedule the job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    OVERWRITE_FIELD_NUMBER: builtins.int
    overwrite: builtins.bool
    """If true, allows this job to overwrite an existing job with the same name."""
    @property
    def job(self) -> Global___Job:
        """The job details."""

    def __init__(
        self,
        *,
        job: Global___Job | None = ...,
        overwrite: builtins.bool = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["job", b"job"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["job", b"job", "overwrite", b"overwrite"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ScheduleJobRequest: typing_extensions.TypeAlias = ScheduleJobRequest

@typing.final
class ScheduleJobResponse(google.protobuf.message.Message):
    """ScheduleJobResponse is the message response to create/schedule the job.
    Empty
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ScheduleJobResponse: typing_extensions.TypeAlias = ScheduleJobResponse

@typing.final
class GetJobRequest(google.protobuf.message.Message):
    """GetJobRequest is the message to retrieve a job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the job."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetJobRequest: typing_extensions.TypeAlias = GetJobRequest

@typing.final
class GetJobResponse(google.protobuf.message.Message):
    """GetJobResponse is the message's response for a job retrieved."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> Global___Job:
        """The job details."""

    def __init__(
        self,
        *,
        job: Global___Job | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["job", b"job"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["job", b"job"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetJobResponse: typing_extensions.TypeAlias = GetJobResponse

@typing.final
class DeleteJobRequest(google.protobuf.message.Message):
    """DeleteJobRequest is the message to delete the job by name."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the job."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteJobRequest: typing_extensions.TypeAlias = DeleteJobRequest

@typing.final
class DeleteJobResponse(google.protobuf.message.Message):
    """DeleteJobResponse is the message response to delete the job by name.
    Empty
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DeleteJobResponse: typing_extensions.TypeAlias = DeleteJobResponse

@typing.final
class DeleteJobsByPrefixRequestAlpha1(google.protobuf.message.Message):
    """DeleteJobsByPrefixRequest is the message to delete jobs by name prefix."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    """name_prefix is the prefix of the job names to delete. If not provided, all
    jobs associated with this app ID will be deleted.
    """
    def __init__(
        self,
        *,
        name_prefix: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_name_prefix", b"_name_prefix", "name_prefix", b"name_prefix"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_name_prefix", b"_name_prefix", "name_prefix", b"name_prefix"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__name_prefix: typing_extensions.TypeAlias = typing.Literal["name_prefix"]
    _WhichOneofArgType__name_prefix: typing_extensions.TypeAlias = typing.Literal["_name_prefix", b"_name_prefix"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType__name_prefix) -> _WhichOneofReturnType__name_prefix | None: ...

Global___DeleteJobsByPrefixRequestAlpha1: typing_extensions.TypeAlias = DeleteJobsByPrefixRequestAlpha1

@typing.final
class DeleteJobsByPrefixResponseAlpha1(google.protobuf.message.Message):
    """Empty"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DeleteJobsByPrefixResponseAlpha1: typing_extensions.TypeAlias = DeleteJobsByPrefixResponseAlpha1

@typing.final
class ListJobsRequestAlpha1(google.protobuf.message.Message):
    """Empty"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ListJobsRequestAlpha1: typing_extensions.TypeAlias = ListJobsRequestAlpha1

@typing.final
class ListJobsResponseAlpha1(google.protobuf.message.Message):
    """ListJobsResponse is the message response containing the list of jobs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Job]:
        """The list of jobs."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[Global___Job] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["jobs", b"jobs"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListJobsResponseAlpha1: typing_extensions.TypeAlias = ListJobsResponseAlpha1



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dapr/proto/runtime/v1/binding.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dapr/proto/runtime/v1/binding.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dapr/proto/runtime/v1/binding.proto\x12\x15\x64\x61pr.proto.runtime.v1\"\xc3\x01\n\x14InvokeBindingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12K\n\x08metadata\x18\x03 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry\x12\x11\n\toperation\x18\x04 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x15InvokeBindingResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.binding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INVOKEBINDINGREQUEST']._serialized_start=63
  _globals['_INVOKEBINDINGREQUEST']._serialized_end=258
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_start=211
  _globals['_INVOKEBINDINGREQUEST_METADATAENTRY']._serialized_end=258
  _globals['_INVOKEBINDINGRESPONSE']._serialized_start=261
  _globals['_INVOKEBINDINGRESPONSE']._serialized_end=425
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_start=211
  _globals['_INVOKEBINDINGRESPONSE_METADATAENTRY']._serialized_end=258
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

Copyright 2025 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TryLockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    LOCK_OWNER_FIELD_NUMBER: builtins.int
    EXPIRY_IN_SECONDS_FIELD_NUMBER: builtins.int
    store_name: builtins.str
    """Required. The lock store name,e.g. `redis`."""
    resource_id: builtins.str
    """Required. resource_id is the lock key. e.g. `order_id_111`
    It stands for "which resource I want to protect"
    """
    lock_owner: builtins.str
    """Required. lock_owner indicate the identifier of lock owner.
    You can generate a uuid as lock_owner.For example,in golang:

    req.LockOwner = uuid.New().String()

    This field is per request,not per process,so it is different for each request,
    which aims to prevent multi-thread in the same process trying the same lock concurrently.

    The reason why we don't make it automatically generated is:
    1. If it is automatically generated,there must be a 'my_lock_owner_id' field in the response.
      This name is so weird that we think it is inappropriate to put it into the api spec
    2. If we change the field 'my_lock_owner_id' in the response to 'lock_owner',which means the current lock owner of this lock,
      we find that in some lock services users can't get the current lock owner.Actually users don't need it at all.
    3. When reentrant lock is needed,the existing lock_owner is required to identify client and check "whether this client can reenter this lock".
      So this field in the request shouldn't be removed.
    """
    expiry_in_seconds: builtins.int
    """Required. The time before expiry.The time unit is second."""
    def __init__(
        self,
        *,
        store_name: builtins.str = ...,
        resource_id: builtins.str = ...,
        lock_owner: builtins.str = ...,
        expiry_in_seconds: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["expiry_in_seconds", b"expiry_in_seconds", "lock_owner", b"lock_owner", "resource_id", b"resource_id", "store_name", b"store_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___TryLockRequest: typing_extensions.TypeAlias = TryLockRequest

@typing.final
class TryLockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___TryLockResponse: typing_extensions.TypeAlias = TryLockResponse

@typing.final
class UnlockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    LOCK_OWNER_FIELD_NUMBER: builtins.int
    store_name: builtins.str
    resource_id: builtins.str
    """resource_id is the lock key."""
    lock_owner: builtins.str
    def __init__(
        self,
        *,
        store_name: builtins.str = ...,
        resource_id: builtins.str = ...,
        lock_owner: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["lock_owner", b"lock_owner", "resource_id", b"resource_id", "store_name", b"store_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UnlockRequest: typing_extensions.TypeAlias = UnlockRequest

@typing.final
class UnlockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UnlockResponse._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUCCESS: UnlockResponse._Status.ValueType  # 0
        LOCK_DOES_NOT_EXIST: UnlockResponse._Status.ValueType  # 1
        LOCK_BELONGS_TO_OTHERS: UnlockResponse._Status.ValueType  # 2
        INTERNAL_ERROR: UnlockResponse._Status.ValueType  # 3

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    SUCCESS: UnlockResponse.Status.ValueType  # 0
    LOCK_DOES_NOT_EXIST: UnlockResponse.Status.ValueType  # 1
    LOCK_BELONGS_TO_OTHERS: UnlockResponse.Status.ValueType  # 2
    INTERNAL_ERROR: UnlockResponse.Status.ValueType  # 3

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___UnlockResponse.Status.ValueType
    def __init__(
        self,
        *,
        status: Global___UnlockResponse.Status.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UnlockResponse: typing_extensions.TypeAlias = UnlockResponse
